Index: dm/DMUtil.h |
diff --git a/dm/DMUtil.h b/dm/DMUtil.h |
index 1145f28221014b5f8a1b7e25c451750086b0bcea..c2083ba0cb9c4b0b0c691c2211c07f951a22e301 100644 |
--- a/dm/DMUtil.h |
+++ b/dm/DMUtil.h |
@@ -20,10 +20,11 @@ SkPicture* RecordPicture(skiagm::GM* gm, |
uint32_t recordFlags = 0, |
SkBBHFactory* factory = NULL); |
// Prepare bitmap to have gm or bench draw into it with this config. |
// TODO(mtklein): make SkBenchmark::getSize()/GM::getISize() const. |
-void SetupBitmap(const SkColorType, skiagm::GM* gm, SkBitmap* bitmap); |
-void SetupBitmap(const SkColorType, SkBenchmark* bench, SkBitmap* bitmap); |
+void SetupBitmap(SkColorType, skiagm::GM* gm, SkBitmap* bitmap); |
+void SetupBitmap(SkColorType, SkBenchmark* bench, SkBitmap* bitmap); |
+void SetupBitmap(SkColorType, const SkPicture& picture, SkBitmap* bitmap); |
// Draw picture to bitmap. |
void DrawPicture(SkPicture* picture, SkBitmap* bitmap); |
@@ -20,10 +20,11 @@ SkPicture* RecordPicture(skiagm::GM* gm, |
uint32_t recordFlags = 0, |
SkBBHFactory* factory = NULL); |
-// Prepare bitmap to have gm or bench draw into it with this config. |
+// Prepare bitmap to have gm, bench or picture draw into it with this config. |
// TODO(mtklein): make SkBenchmark::getSize()/GM::getISize() const. |